@@ -28,6 +28,7 @@ static const char *default_srv_config = "{"
     "\"queue_timeout\":        6,"
     "\"queue_timeout_2\":      8,"
     "\"cssurls\":              [\"\"],"
+    "\"def_timeline_entries\": 50,"
     "\"max_timeline_entries\": 50,"
     "\"timeline_purge_days\":  120,"
     "\"local_purge_days\":     0,"
@@ -36,6 +37,7 @@ static const char *default_srv_config = "{"
     "\"admin_account\":        \"\","
     "\"title\":                \"\","
     "\"short_description\":    \"\","
+    "\"short_description_raw\": false,"
     "\"protocol\":             \"https\","
     "\"fastcgi\":              false"
     "}";
@@ -57,6 +59,7 @@ static const char *default_css =
     ".snac-top-controls { padding-bottom: 1.5em }\n"
     ".snac-post { border-top: 1px solid #a0a0a0; padding-top: 0.5em; padding-bottom: 0.5em; }\n"
     ".snac-children { padding-left: 1em; border-left: 1px solid #a0a0a0; }\n"
+    ".snac-thread-cont { border-top: 1px dashed #a0a0a0; }\n"
     ".snac-textarea { font-family: inherit; width: 100% }\n"
     ".snac-history { border: 1px solid #606060; border-radius: 3px; margin: 2.5em 0; padding: 0 2em }\n"
     ".snac-btn-mute { float: right; margin-left: 0.5em }\n"
@@ -72,6 +75,7 @@ static const char *default_css =
     ".snac-list-of-lists { padding-left: 0; }\n"
     ".snac-list-of-lists li { display: inline; border: 1px solid #a0a0a0; border-radius: 25px;\n"
     "  margin-right: 0.5em; padding-left: 0.5em; padding-right: 0.5em; }\n"
+    ".snac-no-more-unseen-posts { border-top: 1px solid #a0a0a0; border-bottom: 1px solid #a0a0a0; padding: 0.5em 0; margin: 1em 0; }\n"
     "@media (prefers-color-scheme: dark) { \n"
     "  body, input, textarea { background-color: #000; color: #fff; }\n"
     "  a { color: #7799dd }\n"
@@ -878,7 +882,7 @@ void import_csv(snac *user)
             if (*l) {
                 xs *post = NULL;
 
-                if (!object_get(l, &post)) {
+                if (!valid_status(object_get(l, &post))) {
                     if (!valid_status(activitypub_request(user, l, &post))) {
                         snac_log(user, xs_fmt("Error getting object %s for bookmarking", l));
                         continue;
