@@ -1,4 +1,4 @@
-/* copyright (c) 2022 - 2024 grunfink et al. / MIT license */
+/* copyright (c) 2022 - 2025 grunfink et al. / MIT license */
 
 #ifndef _XS_CURL_H
 
@@ -9,6 +9,8 @@ xs_dict *xs_http_request(const char *method, const char *url,
                         const xs_str *body, int b_size, int *status,
                         xs_str **payload, int *p_size, int timeout);
 
+const char *xs_curl_strerr(int errnum);
+
 #ifdef XS_IMPLEMENTATION
 
 #include <curl/curl.h>
@@ -146,8 +148,7 @@ xs_dict *xs_http_request(const char *method, const char *url,
     }
 
     /* fill the request headers */
-    int c = 0;
-    while (xs_dict_next(headers, &k, &v, &c)) {
+    xs_dict_foreach(headers, k, v) {
         xs *h = xs_fmt("%s: %s", k, v);
 
         list = curl_slist_append(list, h);
@@ -195,6 +196,15 @@ xs_dict *xs_http_request(const char *method, const char *url,
     return response;
 }
 
+
+const char *xs_curl_strerr(int errnum)
+{
+    CURLcode cc = errnum < 0 ? -errnum : errnum;
+
+    return curl_easy_strerror(cc);
+}
+
+
 #endif /* XS_IMPLEMENTATION */
 
 #endif /* _XS_CURL_H */
